@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Server::AUTHORITY = 'cpan:DDG';
 }
 # ABSTRACT: Starting up the web server to test instant answers
-$App::DuckPAN::Cmd::Server::VERSION = '0.146';
+$App::DuckPAN::Cmd::Server::VERSION = '0.147';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -40,8 +40,11 @@ has page_templates_filename => (
 	is => 'rw',
 );
 
-has page_css_filename => (
+# We set this into an array because there can be multiple
+# CSS files in the page.
+has page_css_filenames => (
 	is => 'rw',
+    default => sub { [] },
 );
 
 has hostname => (
@@ -143,7 +146,12 @@ sub run {
 	# Pull files out of cache to be served later by DuckPAN server
 	my $page_root = io(file($self->app->cfg->cache_path,'page_root.html'))->slurp;
 	my $page_spice = io(file($self->app->cfg->cache_path,'page_spice.html'))->slurp;
-	my $page_css = io(file($self->app->cfg->cache_path,$self->page_css_filename))->slurp;
+    
+    # Since there are multiple CSS files to slurp in,
+    # we iterate through each one.
+	my $page_css = join('', map { 
+    	io(file($self->app->cfg->cache_path, $_))->slurp;
+    } @{$self->page_css_filenames});
 	my $page_js = io(file($self->app->cfg->cache_path,$self->page_js_filename))->slurp;
 
 	# Concatenate duckpan.js to g.js
@@ -211,10 +219,18 @@ sub change_html {
 	# Make sure DuckPAN serves DDG CSS (already pulled down at startup)
 	# ie <link href="/s123.css"> becomes <link href="/?duckduckhack_css=1">
 	# Also rewrite relative links to hostname
-	for (@a,@link) {
-
+    my $has_css = 0;
+	for (@a, @link) {
 		if ($_->attr('type') && $_->attr('type') eq 'text/css') {
-			$_->attr('href','/?duckduckhack_css=1');
+        	# We only want to load the CSS file once.
+            # We only load it once because /?duckduckhack_css=1 already has all of the CSS
+            # in a single page.
+        	unless($has_css) {
+				$_->attr('href','/?duckduckhack_css=1');
+            	$has_css = 1;
+            } else {
+            	$_->attr('href','/?duckduckhack_ignore=1');
+            }
 		} elsif (defined $_->attr('href') && substr($_->attr('href'),0,1) eq '/') {
 			$_->attr('href','http://'.$self->hostname.''.$_->attr('href'));
 		}
@@ -307,15 +323,17 @@ sub get_assets {
 	for (@link) {
 		if ($_->attr('type') && $_->attr('type') eq 'text/css') {
 			if (my $href = $_->attr('href')) {
-				if ($href =~ m/^\/((?:s\d+|style)\.css)/) {
-					$self->page_css_filename($1);
+            	# We're looking for txxx.css and sxxx.css.
+                # style.css and static.css are for development mode.
+				if ($href =~ m/^\/((?:[st]\d+|style|static)\.css)/) {
+                	push(@{$self->page_css_filenames}, $1);
 				}
 			}
 		}
 	}
 
 	# Check if we need to request any new assets from hostname, otherwise use cached copies
-	for my $curr_asset ($self->page_js_filename, $self->page_templates_filename, $self->page_css_filename) {
+    for my $curr_asset ($self->page_js_filename, $self->page_templates_filename, @{$self->page_css_filenames}) {
 		# Request file unless cache is disabled, or cache already contains file
 		if ($self->no_cache || ! -f file($self->app->cfg->cache_path,$curr_asset)) {
 			my $url = 'http://'.$self->hostname.'/'.$curr_asset;
@@ -355,7 +373,7 @@ App::DuckPAN::Cmd::Server - Starting up the web server to test instant answers
 
 =head1 VERSION
 
-version 0.146
+version 0.147
 
 =head1 AUTHOR
 
